summaryrefslogtreecommitdiff
path: root/test/rdoc/minitest_helper.rb
diff options
context:
space:
mode:
Diffstat (limited to 'test/rdoc/minitest_helper.rb')
-rw-r--r--test/rdoc/minitest_helper.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/rdoc/minitest_helper.rb b/test/rdoc/minitest_helper.rb
index 5db0c315ef..50e41ebdd2 100644
--- a/test/rdoc/minitest_helper.rb
+++ b/test/rdoc/minitest_helper.rb
@@ -189,10 +189,10 @@ class RDoc::TestCase < (defined?(Minitest::Test) ? Minitest::Test : MiniTest::Un
end
##
- # run capture_io with setting $VERBOSE = true
+ # run capture_output with setting $VERBOSE = true
- def verbose_capture_io
- capture_io do
+ def verbose_capture_output
+ capture_output do
begin
orig_verbose = $VERBOSE
$VERBOSE = true